%% harptab class by Anthony Labarre © 2010, adapted from article.cls
% 
% This file is part of harpy.
% 
% harpy is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 2 of the License, or
% (at your option) any later version.
% 
% harpy is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with harpy.  If not, see <http://www.gnu.org/licenses/>.
% 
\NeedsTeXFormat{LaTeX2e}[1995/12/01]
\ProvidesClass{harptab}[2010/03/21 Harptab LaTeX class]

\LoadClass{article}

% Begin package section -------------------------------------------------------

\usepackage{amsmath} % \overset, \underset
\usepackage{fancyhdr}
\usepackage{lastpage}
\usepackage{textcomp} % \textuparrow, \textdownarrow
\usepackage{textpos} % \textblock

\pagestyle{fancy}

\fancyhf{}
\fancyhead[R]{}
\fancyfoot[C]{\small Harp tab produced by \texttt{harpy} -- Page \thepage\ of \pageref{LastPage}}
\renewcommand{\headrulewidth}{0pt}
%
\fancypagestyle{plain}{%
  \fancyhf{}
\fancyfoot[C]{\small Harp tab produced by \texttt{harpy} -- Page \thepage\ of \pageref{LastPage}}
  \renewcommand{\headrulewidth}{0pt}
}

% End package section ---------------------------------------------------------

% Begin layout section --------------------------------------------------------

% Information to display:
% title, =\title{}
% composer, =\author
% album, 
% year=\date
% type of harmonica to use
% difficulties (none, bends, tongue blocking, overblows, overdraws

% TODO: handle case where these are empty
\newcommand*{\album}[1]{\def\fromalbum{#1}}
\newcommand*{\instrument}[1]{\def\forinstrument{#1}}
\newcommand*{\keysignature}[1]{\def\forkeysignature{#1}}
\newcommand*{\bpm}[1]{\def\forbpm{#1}}

\renewcommand{\@maketitle}{
  \begin{center}%
  \let \footnote \thanks
    {\LARGE \bfseries\underline{\@title} 
\par
}
    {\large
      \begin{flushright}
        by \@author          \\
        from \fromalbum\\
        Key signature: \forkeysignature\\
        BPM: \forbpm\\
      \end{flushright}
\par
}

  \end{center}%
  \par
  \vskip 1.5em
% Name of instrument in upper right corner (text grows to the left)
\begin{textblock}{3}[0,0](8.6,-2.5)
\begin{flushright}
\fbox{\forinstrument}
\end{flushright}
\end{textblock} 
}

\setlength\topmargin{-0.9in}
% \setlength\headheight{-1in}
% \setlength\headsep{0in}
\setlength\textheight{9in}
% \setlength\textwidth{6.3in}
% \setlength\oddsidemargin{0in}
% \setlength\evensidemargin{0in}
\setlength\parindent{0in}
% \setlength\parskip{0.25in}

% End layout section ----------------------------------------------------------

% Begin harmonica specific commands -------------------------------------------

% If I later choose to offer different styles, this style will be selected by a 
% ``default'' option

\newcommand{\blow}[1]{\mbox{#1\textuparrow}}
\newcommand{\draw}[1]{\mbox{#1\textdownarrow}}
\newcommand{\halfbendblow}[1]{\blow{\ensuremath{\overline{#1}}}}
\newcommand{\fullbendblow}[1]{\blow{\ensuremath{\overline{\overline{#1}}}}}
\newcommand{\halfbenddraw}[1]{\draw{\ensuremath{\overline{#1}}}}
\newcommand{\fullbenddraw}[1]{\draw{\ensuremath{\overline{\overline{#1}}}}}

\newcommand{\overfullbendblow}[1]{%
\blow{\ensuremath{\overline{\overline{\overline{#1}}}}}%
}

\newcommand{\overfullbenddraw}[1]{%
\draw{\ensuremath{\overline{\overline{\overline{#1}}}}}%
}

% TODO: \blow{\bend{6}{2}} will work, but not \bend{\blow{6}}{2}
% I'm fine with that, but I should prevent the user from doing that

\newcommand{\chord}[1]{\ensuremath{\{#1\}}}
\newcommand{\tremolo}[1]{\ensuremath{<#1>}}
\newcommand{\overblow}[1]{\mbox{\ensuremath{\underset{\circ}{#1}}\textuparrow}}
\newcommand{\overdraw}[1]{\mbox{\ensuremath{\overset{\circ}{#1}}\textdownarrow}}

% End harmonica specific commands ---------------------------------------------
